@@ -43,7 +43,7 @@ public:
     {
     }
 
-    Q_REQUIRED_RESULT QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override
+    [[nodiscard]] QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override
     {
         if (index.row() < 0 || index.row() >= mRights.count()) {
             return {};
@@ -87,7 +87,7 @@ public:
         return false;
     }
 
-    Q_REQUIRED_RESULT int rowCount(const QModelIndex &parent = QModelIndex()) const override
+    [[nodiscard]] int rowCount(const QModelIndex &parent = QModelIndex()) const override
     {
         if (parent.isValid()) {
             return 0;
@@ -111,7 +111,7 @@ public:
         endResetModel();
     }
 
-    Q_REQUIRED_RESULT QMap<QByteArray, KIMAP::Acl::Rights> rights() const
+    [[nodiscard]] QMap<QByteArray, KIMAP::Acl::Rights> rights() const
     {
         QMap<QByteArray, KIMAP::Acl::Rights> result;
 
@@ -147,7 +147,7 @@ protected:
     }
 
 private:
-    QVector<QPair<QByteArray, KIMAP::Acl::Rights>> mRights;
+    QList<QPair<QByteArray, KIMAP::Acl::Rights>> mRights;
 };
 
 class Q_DECL_HIDDEN PimCommon::AclManager::AclManagerPrivate
@@ -278,12 +278,14 @@ public:
                 == KMessageBox::warningContinueCancel(nullptr,
                                                       i18n("Do you really want to remove your own permissions for this folder? "
                                                            "You will not be able to access it afterwards."),
-                                                      i18n("Remove"))) {
+                                                      i18nc("@title:window", "Remove"))) {
                 return;
             }
         } else {
             if (KMessageBox::Cancel
-                == KMessageBox::warningContinueCancel(nullptr, i18n("Do you really want to remove these permissions for this folder?"), i18n("Remove"))) {
+                == KMessageBox::warningContinueCancel(nullptr,
+                                                      i18n("Do you really want to remove these permissions for this folder?"),
+                                                      i18nc("@title:window", "Remove"))) {
                 return;
             }
         }
